HivePluginAction class sealed

Available extensions
Annotations
  • @Freezed.new(unionKey: "action")

Constructors

HivePluginAction.fromJson(Map<String, dynamic> json)
factory
HivePluginAction.getBoxList(String projectName)
const
factory
HivePluginAction.getKeys(String projectName, String boxName)
const
factory
HivePluginAction.getValue(String projectName, String key, String boxName)
const
factory

Properties

copyWith → $HivePluginActionCopyWith<HivePluginAction>
Create a copy of HivePluginAction with the given fields replaced by the non-null parameter values.
no setterinherited
handleType → HiveGetTypes

Available on HivePluginAction, provided by the HivePluginActionEx extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
projectName → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult getKeys(HiveGetKeys value), required TResult getBoxList(HiveGetBoxs value), required TResult getValue(HiveGetValue value)}) → TResult

Available on HivePluginAction, provided by the HivePluginActionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? getKeys(HiveGetKeys value)?, TResult? getBoxList(HiveGetBoxs value)?, TResult? getValue(HiveGetValue value)?}) → TResult?

Available on HivePluginAction, provided by the HivePluginActionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult getKeys(HiveGetKeys value)?, TResult getBoxList(HiveGetBoxs value)?, TResult getValue(HiveGetValue value)?, required TResult orElse()}) → TResult

Available on HivePluginAction, provided by the HivePluginActionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult getKeys(String projectName, String boxName)?, TResult getBoxList(String projectName)?, TResult getValue(String projectName, String key, String boxName)?, required TResult orElse()}) → TResult

Available on HivePluginAction, provided by the HivePluginActionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this HivePluginAction to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult getKeys(String projectName, String boxName), required TResult getBoxList(String projectName), required TResult getValue(String projectName, String key, String boxName)}) → TResult

Available on HivePluginAction, provided by the HivePluginActionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? getKeys(String projectName, String boxName)?, TResult? getBoxList(String projectName)?, TResult? getValue(String projectName, String key, String boxName)?}) → TResult?

Available on HivePluginAction, provided by the HivePluginActionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited