ResponseModel class sealed

Available extensions
Annotations
  • @freezed

Constructors

ResponseModel(String json, String type)
const
factory
ResponseModel.fromJson(dynamic json)
factory

Properties

copyWith → $ResponseModelCopyWith<ResponseModel>
Create a copy of ResponseModel with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initMessage → String

Available on ResponseModel, provided by the ResponseModelExtends extension

no setter
json → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tryParseJson → Map<String, dynamic>

Available on ResponseModel, provided by the ResponseModelExtends extension

尝试解析json-> Map
no setter
type → String
no setterinherited

Methods

handle() → void

Available on ResponseModel, provided by the ResponseModelExtends extension

对idea插件端的数据进行处理
map<TResult extends Object?>(TResult $default(_ResponseModel value)) → TResult

Available on ResponseModel, provided by the ResponseModelPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ResponseModel value)?) → TResult?

Available on ResponseModel, provided by the ResponseModelPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ResponseModel value)?, {required TResult orElse()}) → TResult

Available on ResponseModel, provided by the ResponseModelPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String json, String type)?, {required TResult orElse()}) → TResult

Available on ResponseModel, provided by the ResponseModelPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ResponseModel to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String json, String type)) → TResult

Available on ResponseModel, provided by the ResponseModelPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String json, String type)?) → TResult?

Available on ResponseModel, provided by the ResponseModelPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited