SpViewUtil class

Constructors

SpViewUtil()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() → Future<void>
removeAllKey() → Future<void>
removeKey(String key) → Future<void>
sendAllSpKeys(SocketConnect socketConnect) → Future<void>
发送keys到Swift客户端
sendSpValueToSwift(SwiftSpGetValueAction action, SocketConnect socketConnect) → Future<void>
发送sp key 的值到Swift客户端
toString() → String
A string representation of this object.
inherited
updateBoolValue(String key, bool newValue) → Future<void>
updateDoubleValue(String key, double newValue) → Future<void>
updateIntValue(String key, int newValue) → Future<void>
updateStringValue(String key, String newValue) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited